@@ -228,7 +228,10 @@ print "App::Framework::Core->new() class=$class\n" if $class_debug ;
 		my $tz = $App::Frameowrk::Settings::DATE_TZ || 'GMT' ;
 		my $fmt = $App::Frameowrk::Settings::DATE_FORMAT || 'non-US' ;
 		eval {
-		&Date_Init("TZ=$tz", "DateFormat=$fmt") ;
+			my $date = new Date::Manip::Date;
+			$date->config("setdate", "zone,$tz") ;
+			
+			#&Date_Init("TZ=$tz", "DateFormat=$fmt") ;
 		} ;
 	}
 
